@@ -6,13 +6,14 @@ implementations.
 """
 import numpy as np
 
-from openmdao.components.interp_util.interp_akima import InterpAkima
+from openmdao.components.interp_util.interp_akima import InterpAkima, InterpAkima1D
 from openmdao.components.interp_util.interp_bsplines import InterpBSplines
 from openmdao.components.interp_util.interp_cubic import InterpCubic
 from openmdao.components.interp_util.interp_lagrange2 import InterpLagrange2
 from openmdao.components.interp_util.interp_lagrange3 import InterpLagrange3
 from openmdao.components.interp_util.interp_scipy import InterpScipy
 from openmdao.components.interp_util.interp_slinear import InterpLinear
+from openmdao.components.interp_util.interp_trilinear import InterpTrilinear
 
 from openmdao.components.interp_util.outofbounds_error import OutOfBoundsError
 
@@ -22,14 +23,16 @@ INTERP_METHODS = {
     'lagrange3': InterpLagrange3,
     'cubic': InterpCubic,
     'akima': InterpAkima,
+    'akima1D': InterpAkima1D,
     'scipy_cubic': InterpScipy,
     'scipy_slinear': InterpScipy,
     'scipy_quintic': InterpScipy,
     'bsplines': InterpBSplines,
+    'trilinear': InterpTrilinear,
 }
 
 TABLE_METHODS = ['slinear', 'lagrange2', 'lagrange3', 'cubic', 'akima', 'scipy_cubic',
-                 'scipy_slinear', 'scipy_quintic']
+                 'scipy_slinear', 'scipy_quintic', 'trilinear', 'akima1D']
 SPLINE_METHODS = ['slinear', 'lagrange2', 'lagrange3', 'cubic', 'akima', 'bsplines',
                   'scipy_cubic', 'scipy_slinear', 'scipy_quintic']
 
@@ -43,6 +46,32 @@ class InterpND(object):
     provided for all interpolation methods. Gradients with respect to grid values are also
     available optionally.
 
+    Parameters
+    ----------
+    method : str
+        Name of interpolation method.
+    points : ndarray or tuple of ndarray
+        The points defining the regular grid in n dimensions.
+        For 1D interpolation, this can be an ndarray of table locations.
+        For table interpolation, it can be a tuple or an ndarray. If it is a tuple, it should
+        contain one ndarray for each table dimension.
+        For spline evaluation, num_cp can be specified instead of points.
+    values : ndarray or tuple of ndarray or None
+        These must be specified for interpolation.
+        The data on the regular grid in n dimensions.
+    x_interp : ndarray or None
+        If we are always interpolating at a fixed set of locations, then they can be
+        specified here.
+    extrapolate : bool
+        If False, when interpolated values are requested outside of the domain of the input
+        data, a ValueError is raised. If True, then the methods are allowed to extrapolate.
+        Default is True (raise an exception).
+    num_cp : None or int
+        Optional. When specified, use a linear distribution of num_cp control points. If you
+        are using 'bsplines' as the method, then num_cp must be set instead of points.
+    **kwargs : dict
+        Interpolator-specific options to pass onward.
+
     Attributes
     ----------
     extrapolate : bool
@@ -90,32 +119,6 @@ class InterpND(object):
         For interpolation, specify values and points.
 
         For spline evaluation, specifiy x_interp and either points or num_cp.
-
-        Parameters
-        ----------
-        method : str
-            Name of interpolation method.
-        points : ndarray or tuple of ndarray
-            The points defining the regular grid in n dimensions.
-            For 1D interpolation, this can be an ndarray of table locations.
-            For table interpolation, it can be a tuple or an ndarray. If it is a tuple, it should
-            contain one ndarray for each table dimension.
-            For spline evaluation, num_cp can be specified instead of points.
-        values : ndarray or tuple of ndarray or None
-            These must be specified for interpolation.
-            The data on the regular grid in n dimensions.
-        x_interp : ndarray or None
-            If we are always interpolating at a fixed set of locations, then they can be
-            specified here.
-        extrapolate : bool
-            If False, when interpolated values are requested outside of the domain of the input
-            data, a ValueError is raised. If True, then the methods are allowed to extrapolate.
-            Default is True (raise an exception).
-        num_cp : None or int
-            Optional. When specified, use a linear distribution of num_cp control points. If you
-            are using 'bsplines' as the method, then num_cp must be set instead of points.
-        **kwargs : dict
-            Interpolator-specific options to pass onward.
         """
         if not isinstance(method, str):
             msg = "Argument 'method' should be a string."
@@ -219,7 +222,7 @@ class InterpND(object):
             Value of interpolant at all sample points.
         ndarray
             Value of derivative of interpolated output with respect to input x. (Only when
-            compute_derivative is True.)
+            compute_derivative is True).
         """
         self._compute_d_dx = compute_derivative
         self.table._compute_d_dx = compute_derivative
@@ -272,7 +275,7 @@ class InterpND(object):
         result = self._evaluate_spline(values)
         if result.shape[0] == 1:
             # Not vectorized, so drop the extra dimension.
-            result = result.flatten()
+            result = result.ravel()
 
         if compute_derivative:
             d_dvalues = self.spline_gradient()
@@ -323,10 +326,14 @@ class InterpND(object):
             # each iteration.
             interp = self._interp
             self.table = interp(self.grid, self.values, interp, **self._interp_options)
+            if not self.table._supports_d_dvalues:
+                raise RuntimeError(f'Method {self.table._name} does not support the '
+                                   '"training_data_gradients" option.')
+
             self.table._compute_d_dvalues = True
 
         table = self.table
-        if table._vectorized:
+        if table.vectorized(xi):
             result, derivs_x, derivs_val, derivs_grid = table.evaluate_vectorized(xi)
 
         else:
@@ -340,7 +347,7 @@ class InterpND(object):
             for j in range(n_nodes):
                 val, d_x, d_values, d_grid = table.evaluate(xi[j, :])
                 result[j] = val
-                derivs_x[j, :] = d_x.flatten()
+                derivs_x[j, :] = d_x.ravel()
                 if d_values is not None:
                     if derivs_val is None:
                         dv_shape = [n_nodes]
@@ -454,11 +461,11 @@ class InterpND(object):
         Parameters
         ----------
         xi : ndarray of shape (..., ndim)
-            The coordinates to sample the gridded data at
+            The coordinates to sample the gridded data at.
 
         Returns
         -------
-        gradient : ndarray of shape (..., ndim)
+        ndarray
             Vector of gradients of the interpolated values with respect to each value in xi.
         """
         if (self._xi is None) or (not np.array_equal(xi, self._xi)):
